@@ -101,6 +101,10 @@ class Addon(clickpoints.Addon):
             self.db.setMarkerType("DM_scalebox", [0, 255, 255], self.db.TYPE_Normal)
             self.cp.reloadTypes()
 
+        if not self.db.getMarkerType("DM_GPS"):
+            self.db.setMarkerType("DM_GPS", [128, 128, 255], self.db.TYPE_Normal)
+            self.cp.reloadTypes()
+
         # TODO: move to parameter
         self.scalebox_dim = 10 # in meter
         self.scalebox_dict = dict()
@@ -239,7 +243,7 @@ class Addon(clickpoints.Addon):
         self.cameraComboBox = AddQComboBox(self.camera_layout,'Model:', values=cam_dict.keys())
         self.cameraComboBox.currentIndexChanged.connect(self.getCameraParametersByJson)
 
-        self.openFile = AddQOpenFileChoose(self.camera_layout, "Input", "", file_type="*.ct")
+        self.openFile = AddQOpenFileChoose(self.camera_layout, "Input", "", file_type="*.*")
         self.openFile.textChanged.connect(self.getCameraParametersByCT)
 
         # self.cameraButton = QtWidgets.QPushButton('Load Cam')
@@ -279,7 +283,15 @@ class Addon(clickpoints.Addon):
         self.leCamPan = AddQLineEdit(self.position_layout,"camera pan:", editwidth=120, value=None)
         self.leCamLat = AddQLineEdit(self.position_layout,"camera latitude:", editwidth=120)
         self.leCamLon = AddQLineEdit(self.position_layout,"camera longitude:", editwidth=120)
+        self.leCamPosX = AddQLineEdit(self.position_layout,"camera position X:", editwidth=120)
+        self.leCamPosY = AddQLineEdit(self.position_layout,"camera position Y:", editwidth=120)
 
+        for c in self.position_groupbox.children():
+            if hasattr(c, "editingFinished"):
+                c.editingFinished.connect(self.update)
+        for c in self.camera_groupbox.children():
+            if hasattr(c, "editingFinished"):
+                c.editingFinished.connect(self.update)
         # get current frame
         cframe = self.cp.getCurrentFrame()
 
@@ -442,6 +454,9 @@ class Addon(clickpoints.Addon):
         self.leCamLat.setText(getNumber(cam.gps_lat,"%.2f"))
         self.leCamLon.setText(getNumber(cam.gps_lon,"%.2f"))
 
+        self.leCamPosX.setText(getNumber(cam.pos_x_m,"%.2f"))
+        self.leCamPosY.setText(getNumber(cam.pos_y_m,"%.2f"))
+
         self.updateCameraParameters()
 
 
@@ -472,8 +487,8 @@ class Addon(clickpoints.Addon):
         self.cam.roll_deg = getFloat(self.leCamRoll.text())
 
         self.cam.elevation_m = getFloat(self.leCamElevation.text())
-        self.cam.pos_x_m = 0.
-        self.cam.pos_y_m = 0.
+        self.cam.pos_x_m = getFloat(self.leCamPosX.text())
+        self.cam.pos_y_m = getFloat(self.leCamPosY.text())
 
         self.cam.projection = self.cbProjection.itemText(self.cbProjection.currentIndex())
 
@@ -547,6 +562,7 @@ class Addon(clickpoints.Addon):
                                                   center_x_px=self.cam.center_x_px,
                                                   center_y_px=self.cam.center_y_px)
         self.camera = ct.Camera(orientation=orientation, projection=projection)
+        self.camera.setGPSpos(lat=self.cam.gps_lat, lon=self.cam.gps_lon, elevation=self.cam.elevation_m)
 
 
     def run(self, start_frame=0):
@@ -652,23 +668,24 @@ class Addon(clickpoints.Addon):
     def plotHorizon(self):
 
         if self.cbShowHorizon.isChecked():
-                # delete old horizon
-                self.deleteHorizon()
+            # delete old horizon
+            self.deleteHorizon()
 
-                # get coordinates
-                p1 = self.camera.getImageHorizon()[0]
-                p2 = self.camera.getImageHorizon()[-1]
-                print(p1, p2)
+            # get coordinates
+            p1 = self.camera.getImageHorizon()[0]
+            p2 = self.camera.getImageHorizon()[-1]
+            print(p1, p2)
 
-                # set pen
-                pen = QtGui.QPen(QtGui.QColor("#00ffff"))
-                pen.setWidth(5)
+            # set pen
+            pen = QtGui.QPen(QtGui.QColor("#00ffff"))
+            pen.setWidth(5)
+            pen.setCosmetic(True)
 
-                # add object
-                self.horizon_line = QtWidgets.QGraphicsLineItem(QtCore.QLineF(QtCore.QPointF(*p1),QtCore.QPointF(*p2)))
-                self.horizon_line.setPen(pen)
-                self.horizon_line.setParentItem(self.cp.window.view.origin)
-                self.horizon_line.setZValue(100)
+            # add object
+            self.horizon_line =  QtWidgets.QGraphicsLineItem(QtCore.QLineF(QtCore.QPointF(*p1), QtCore.QPointF(*p2)))
+            self.horizon_line.setPen(pen)
+            self.horizon_line.setParentItem(self.cp.window.view.origin)
+            self.horizon_line.setZValue(100)
 
         else:
             self.deleteHorizon()
@@ -679,6 +696,9 @@ class Addon(clickpoints.Addon):
             self.horizon_line.scene().removeItem(self.horizon_line)
             self.horizon_line = None
 
+    def update(self):
+        self.updateCameraParameters()
+        self.updateAllMarker()
 
     def updateAllMarker(self):
 
@@ -697,6 +717,13 @@ class Addon(clickpoints.Addon):
         for marker in distscalebox:
             self.updateScalebox(marker)
 
+        # get scalebox markers and update size
+        gpsMarkers = self.db.getMarkers(type="DM_GPS", frame=self.frame)
+        for marker in gpsMarkers:
+            self.updateGPS(marker)
+        self.cp.reloadMarker(frame=self.frame)
+
+        self.plotHorizon()
 
         self.cp.reloadMarker(frame=self.frame)
 
@@ -723,8 +750,6 @@ class Addon(clickpoints.Addon):
         line.text = "%.2fm" % dist
         line.save()
 
-
-
     def updateScalebox(self,marker):
         scalebox_dim = self.sbScaleboxDim.value()
         if marker.id in self.scalebox_dict:
@@ -744,6 +769,23 @@ class Addon(clickpoints.Addon):
         sb = ScaleBox(self.cp.window.view.origin, '#ff5f00', np.array([marker.x,marker.y]), self.camera, scalebox_dim)
         self.scalebox_dict[marker.id] = sb
 
+    def updateGPS(self, marker):
+        locationData = json.loads(marker.style)
+        if "lon" in locationData and "lat" in locationData:
+            lon = locationData["lon"]
+            lat = locationData["lat"]
+            if "h" in locationData:
+                h = locationData["h"]
+            else:
+                h = 0
+            imagePos = self.camera.imageFromSpace(self.camera.spaceFromGPS(np.array([lat,lon,h])), hide_backpoints=False)
+            if np.all(~np.isnan(imagePos)):
+                marker.x = imagePos[0]
+                marker.y = imagePos[1]
+                marker.save()
+            else:
+                print("gps position of marker is not in Image!")
+        # pass
 
 
     def markerMoveEvent(self, marker):
