@@ -72,6 +72,7 @@ class PseudoSlide:
         self.dimensions = (image.shape[1], image.shape[0])
         self.ndim = len(image.shape)
         self.shape = image.shape
+        self.dtype = image.dtype
 
         self.level_dimensions = []
         self.level_downsamples = []
@@ -200,6 +201,7 @@ def date_linspace(start_date, end_date, frames):
 class DataFileExtended(DataFile):
     def __init__(self, database_filename: Optional[str] = None, config: Optional[dotdict] = None,
                  storage_path: Optional[str] = None) -> None:
+        database_filename = str(database_filename)
         self.exists = os.path.exists(database_filename)
         self._config = config
         self.temporary_db = None
@@ -614,6 +616,8 @@ class DataFileExtended(DataFile):
             except:
                 pass
             self.temporary_db = None
+        # close main db
+        self.db.close()
         pass
 
     def initTimeStampRegEx(self) -> None:
@@ -731,8 +735,8 @@ class DataFileExtended(DataFile):
         if extension.lower() == ".jpg":
             dt = self.getExifTime(file)
             return dt, dt
-        else:
-            print("no time", extension)
+        #else:
+            #print("no time", extension)
         return None, None
 
     def getExifTime(self, path: str) -> None:
@@ -772,15 +776,19 @@ class DataFileExtended(DataFile):
         import dateutil.parser
         reader = tifffile.TiffFile(full_path)
 
+        invalid_timestamps = 0
         ts = []  # timestamp per page (image in the stack)
         for i, page in enumerate(reader.pages):
+            if i == invalid_timestamps and i >= 10:
+                return itertools.repeat(None)
             try:
                 # might fail due to missing meta data, missing key or invalid timestamp format
                 ts.append(dateutil.parser.isoparse((json.loads(page.description)['timestamp'])))
             except Exception as e:
-                print(e)
-                print("ts extraction failed for file %s frame %d" % (full_path, i))
+                #print(e)
+                #print("ts extraction failed for file %s frame %d" % (full_path, i))
                 ts.append(None)
+                invalid_timestamps += 1
 
         return ts
 
